/*!
 *  \file mavlink_info.hh
 *  \brief MAVLink message information.
 *  \author Joshua Harris
 *  \copyright Copyright © 2016-2017 Vehicle Systems & Control Laboratory,
 *  Department of Aerospace Engineering, Texas A&M University
 *  \license ISC License
 */
#pragma once


// 3rd party
#include <QMap>
#include <mavlink/v1/common/mavlink.h>


namespace dfti {


//! Map from MAVLink message ID to human-readable message name.
const QMap<quint8, QString> mavlinkMessageName{
    {MAVLINK_MSG_ID_HEARTBEAT, "HEARTBEAT"},
    {MAVLINK_MSG_ID_SYS_STATUS, "SYS_STATUS"},
    {MAVLINK_MSG_ID_SYSTEM_TIME, "SYSTEM_TIME"},
    {MAVLINK_MSG_ID_PING, "PING"},
    {MAVLINK_MSG_ID_CHANGE_OPERATOR_CONTROL, "CHANGE_OPERATOR_CONTROL"},
    {MAVLINK_MSG_ID_CHANGE_OPERATOR_CONTROL_ACK, "CHANGE_OPERATOR_CONTROL_ACK"},
    {MAVLINK_MSG_ID_AUTH_KEY, "AUTH_KEY"},
    {MAVLINK_MSG_ID_SET_MODE, "SET_MODE"},
    {MAVLINK_MSG_ID_PARAM_REQUEST_READ, "PARAM_REQUEST_READ"},
    {MAVLINK_MSG_ID_PARAM_REQUEST_LIST, "PARAM_REQUEST_LIST"},
    {MAVLINK_MSG_ID_PARAM_VALUE, "PARAM_VALUE"},
    {MAVLINK_MSG_ID_PARAM_SET, "PARAM_SET"},
    {MAVLINK_MSG_ID_GPS_RAW_INT, "GPS_RAW_INT"},
    {MAVLINK_MSG_ID_GPS_STATUS, "GPS_STATUS"},
    {MAVLINK_MSG_ID_SCALED_IMU, "SCALED_IMU"},
    {MAVLINK_MSG_ID_RAW_IMU, "RAW_IMU"},
    {MAVLINK_MSG_ID_RAW_PRESSURE, "RAW_PRESSURE"},
    {MAVLINK_MSG_ID_SCALED_PRESSURE, "SCALED_PRESSURE"},
    {MAVLINK_MSG_ID_ATTITUDE, "ATTITUDE"},
    {MAVLINK_MSG_ID_ATTITUDE_QUATERNION, "ATTITUDE_QUATERNION"},
    {MAVLINK_MSG_ID_LOCAL_POSITION_NED, "LOCAL_POSITION_NED"},
    {MAVLINK_MSG_ID_GLOBAL_POSITION_INT, "GLOBAL_POSITION_INT"},
    {MAVLINK_MSG_ID_RC_CHANNELS_SCALED, "RC_CHANNELS_SCALED"},
    {MAVLINK_MSG_ID_RC_CHANNELS_RAW, "RC_CHANNELS_RAW"},
    {MAVLINK_MSG_ID_SERVO_OUTPUT_RAW, "SERVO_OUTPUT_RAW"},
    {MAVLINK_MSG_ID_MISSION_REQUEST_PARTIAL_LIST, "MISSION_REQUEST_PARTIAL_LIST"},
    {MAVLINK_MSG_ID_MISSION_WRITE_PARTIAL_LIST, "MISSION_WRITE_PARTIAL_LIST"},
    {MAVLINK_MSG_ID_MISSION_ITEM, "MISSION_ITEM"},
    {MAVLINK_MSG_ID_MISSION_REQUEST, "MISSION_REQUEST"},
    {MAVLINK_MSG_ID_MISSION_SET_CURRENT, "MISSION_SET_CURRENT"},
    {MAVLINK_MSG_ID_MISSION_CURRENT, "MISSION_CURRENT"},
    {MAVLINK_MSG_ID_MISSION_REQUEST_LIST, "MISSION_REQUEST_LIST"},
    {MAVLINK_MSG_ID_MISSION_COUNT, "MISSION_COUNT"},
    {MAVLINK_MSG_ID_MISSION_CLEAR_ALL, "MISSION_CLEAR_ALL"},
    {MAVLINK_MSG_ID_MISSION_ITEM_REACHED, "MISSION_ITEM_REACHED"},
    {MAVLINK_MSG_ID_MISSION_ACK, "MISSION_ACK"},
    {MAVLINK_MSG_ID_SET_GPS_GLOBAL_ORIGIN, "SET_GPS_GLOBAL_ORIGIN"},
    {MAVLINK_MSG_ID_GPS_GLOBAL_ORIGIN, "GPS_GLOBAL_ORIGIN"},
    {MAVLINK_MSG_ID_PARAM_MAP_RC, "PARAM_MAP_RC"},
    {MAVLINK_MSG_ID_MISSION_REQUEST_INT, "MISSION_REQUEST_INT"},
    {MAVLINK_MSG_ID_SAFETY_SET_ALLOWED_AREA, "SAFETY_SET_ALLOWED_AREA"},
    {MAVLINK_MSG_ID_SAFETY_ALLOWED_AREA, "SAFETY_ALLOWED_AREA"},
    {MAVLINK_MSG_ID_ATTITUDE_QUATERNION_COV, "ATTITUDE_QUATERNION_COV"},
    {MAVLINK_MSG_ID_NAV_CONTROLLER_OUTPUT, "NAV_CONTROLLER_OUTPUT"},
    {MAVLINK_MSG_ID_GLOBAL_POSITION_INT_COV, "GLOBAL_POSITION_INT_COV"},
    {MAVLINK_MSG_ID_LOCAL_POSITION_NED_COV, "LOCAL_POSITION_NED_COV"},
    {MAVLINK_MSG_ID_RC_CHANNELS, "RC_CHANNELS"},
    {MAVLINK_MSG_ID_REQUEST_DATA_STREAM, "REQUEST_DATA_STREAM"},
    {MAVLINK_MSG_ID_DATA_STREAM, "DATA_STREAM"},
    {MAVLINK_MSG_ID_MANUAL_CONTROL, "MANUAL_CONTROL"},
    {MAVLINK_MSG_ID_RC_CHANNELS_OVERRIDE, "RC_CHANNELS_OVERRIDE"},
    {MAVLINK_MSG_ID_MISSION_ITEM_INT, "MISSION_ITEM_INT"},
    {MAVLINK_MSG_ID_VFR_HUD, "VFR_HUD"},
    {MAVLINK_MSG_ID_COMMAND_INT, "COMMAND_INT"},
    {MAVLINK_MSG_ID_COMMAND_LONG, "COMMAND_LONG"},
    {MAVLINK_MSG_ID_COMMAND_ACK, "COMMAND_ACK"},
    {MAVLINK_MSG_ID_SET_ATTITUDE_TARGET, "SET_ATTITUDE_TARGET"},
    {MAVLINK_MSG_ID_ATTITUDE_TARGET, "ATTITUDE_TARGET"},
    {MAVLINK_MSG_ID_SET_POSITION_TARGET_LOCAL_NED, "SET_POSITION_TARGET_LOCAL_NED"},
    {MAVLINK_MSG_ID_POSITION_TARGET_LOCAL_NED, "POSITION_TARGET_LOCAL_NED"},
    {MAVLINK_MSG_ID_SET_POSITION_TARGET_GLOBAL_INT, "SET_POSITION_TARGET_GLOBAL_INT"},
    {MAVLINK_MSG_ID_POSITION_TARGET_GLOBAL_INT, "POSITION_TARGET_GLOBAL_INT"},
    {MAVLINK_MSG_ID_LOCAL_POSITION_NED_SYSTEM_GLOBAL_OFFSET, "LOCAL_POSITION_NED_SYSTEM_GLOBAL_OFFSET"},
    {MAVLINK_MSG_ID_HIL_STATE, "HIL_STATE"},
    {MAVLINK_MSG_ID_HIL_CONTROLS, "HIL_CONTROLS"},
    {MAVLINK_MSG_ID_HIL_RC_INPUTS_RAW, "HIL_RC_INPUTS_RAW"},
    {MAVLINK_MSG_ID_HIL_ACTUATOR_CONTROLS, "HIL_ACTUATOR_CONTROLS"},
    {MAVLINK_MSG_ID_OPTICAL_FLOW, "OPTICAL_FLOW"},
    {MAVLINK_MSG_ID_GLOBAL_VISION_POSITION_ESTIMATE, "GLOBAL_VISION_POSITION_ESTIMATE"},
    {MAVLINK_MSG_ID_VISION_POSITION_ESTIMATE, "VISION_POSITION_ESTIMATE"},
    {MAVLINK_MSG_ID_VISION_SPEED_ESTIMATE, "VISION_SPEED_ESTIMATE"},
    {MAVLINK_MSG_ID_VICON_POSITION_ESTIMATE, "VICON_POSITION_ESTIMATE"},
    {MAVLINK_MSG_ID_HIGHRES_IMU, "HIGHRES_IMU"},
    {MAVLINK_MSG_ID_OPTICAL_FLOW_RAD, "OPTICAL_FLOW_RAD"},
    {MAVLINK_MSG_ID_HIL_SENSOR, "HIL_SENSOR"},
    {MAVLINK_MSG_ID_SIM_STATE, "SIM_STATE"},
    {MAVLINK_MSG_ID_RADIO_STATUS, "RADIO_STATUS"},
    {MAVLINK_MSG_ID_FILE_TRANSFER_PROTOCOL, "FILE_TRANSFER_PROTOCOL"},
    {MAVLINK_MSG_ID_TIMESYNC, "TIMESYNC"},
    {MAVLINK_MSG_ID_CAMERA_TRIGGER, "CAMERA_TRIGGER"},
    {MAVLINK_MSG_ID_HIL_GPS, "HIL_GPS"},
    {MAVLINK_MSG_ID_HIL_OPTICAL_FLOW, "HIL_OPTICAL_FLOW"},
    {MAVLINK_MSG_ID_HIL_STATE_QUATERNION, "HIL_STATE_QUATERNION"},
    {MAVLINK_MSG_ID_SCALED_IMU2, "SCALED_IMU2"},
    {MAVLINK_MSG_ID_LOG_REQUEST_LIST, "LOG_REQUEST_LIST"},
    {MAVLINK_MSG_ID_LOG_ENTRY, "LOG_ENTRY"},
    {MAVLINK_MSG_ID_LOG_REQUEST_DATA, "LOG_REQUEST_DATA"},
    {MAVLINK_MSG_ID_LOG_DATA, "LOG_DATA"},
    {MAVLINK_MSG_ID_LOG_ERASE, "LOG_ERASE"},
    {MAVLINK_MSG_ID_LOG_REQUEST_END, "LOG_REQUEST_END"},
    {MAVLINK_MSG_ID_GPS_INJECT_DATA, "GPS_INJECT_DATA"},
    {MAVLINK_MSG_ID_GPS2_RAW, "GPS2_RAW"},
    {MAVLINK_MSG_ID_POWER_STATUS, "POWER_STATUS"},
    {MAVLINK_MSG_ID_SERIAL_CONTROL, "SERIAL_CONTROL"},
    {MAVLINK_MSG_ID_GPS_RTK, "GPS_RTK"},
    {MAVLINK_MSG_ID_GPS2_RTK, "GPS2_RTK"},
    {MAVLINK_MSG_ID_SCALED_IMU3, "SCALED_IMU3"},
    {MAVLINK_MSG_ID_DATA_TRANSMISSION_HANDSHAKE, "DATA_TRANSMISSION_HANDSHAKE"},
    {MAVLINK_MSG_ID_ENCAPSULATED_DATA, "ENCAPSULATED_DATA"},
    {MAVLINK_MSG_ID_DISTANCE_SENSOR, "DISTANCE_SENSOR"},
    {MAVLINK_MSG_ID_TERRAIN_REQUEST, "TERRAIN_REQUEST"},
    {MAVLINK_MSG_ID_TERRAIN_DATA, "TERRAIN_DATA"},
    {MAVLINK_MSG_ID_TERRAIN_CHECK, "TERRAIN_CHECK"},
    {MAVLINK_MSG_ID_TERRAIN_REPORT, "TERRAIN_REPORT"},
    {MAVLINK_MSG_ID_SCALED_PRESSURE2, "SCALED_PRESSURE2"},
    {MAVLINK_MSG_ID_ATT_POS_MOCAP, "ATT_POS_MOCAP"},
    {MAVLINK_MSG_ID_SET_ACTUATOR_CONTROL_TARGET, "SET_ACTUATOR_CONTROL_TARGET"},
    {MAVLINK_MSG_ID_ACTUATOR_CONTROL_TARGET, "ACTUATOR_CONTROL_TARGET"},
    {MAVLINK_MSG_ID_ALTITUDE, "ALTITUDE"},
    {MAVLINK_MSG_ID_RESOURCE_REQUEST, "RESOURCE_REQUEST"},
    {MAVLINK_MSG_ID_SCALED_PRESSURE3, "SCALED_PRESSURE3"},
    {MAVLINK_MSG_ID_FOLLOW_TARGET, "FOLLOW_TARGET"},
    {MAVLINK_MSG_ID_CONTROL_SYSTEM_STATE, "CONTROL_SYSTEM_STATE"},
    {MAVLINK_MSG_ID_BATTERY_STATUS, "BATTERY_STATUS"},
    {MAVLINK_MSG_ID_AUTOPILOT_VERSION, "AUTOPILOT_VERSION"},
    {MAVLINK_MSG_ID_LANDING_TARGET, "LANDING_TARGET"},
    {MAVLINK_MSG_ID_ESTIMATOR_STATUS, "ESTIMATOR_STATUS"},
    {MAVLINK_MSG_ID_WIND_COV, "WIND_COV"},
    {MAVLINK_MSG_ID_GPS_INPUT, "GPS_INPUT"},
    {MAVLINK_MSG_ID_GPS_RTCM_DATA, "GPS_RTCM_DATA"},
    {MAVLINK_MSG_ID_HIGH_LATENCY, "HIGH_LATENCY"},
    {MAVLINK_MSG_ID_VIBRATION, "VIBRATION"},
    {MAVLINK_MSG_ID_HOME_POSITION, "HOME_POSITION"},
    {MAVLINK_MSG_ID_SET_HOME_POSITION, "SET_HOME_POSITION"},
    {MAVLINK_MSG_ID_MESSAGE_INTERVAL, "MESSAGE_INTERVAL"},
    {MAVLINK_MSG_ID_EXTENDED_SYS_STATE, "EXTENDED_SYS_STATE"},
    {MAVLINK_MSG_ID_ADSB_VEHICLE, "ADSB_VEHICLE"},
    {MAVLINK_MSG_ID_COLLISION, "COLLISION"},
    {MAVLINK_MSG_ID_V2_EXTENSION, "V2_EXTENSION"},
    {MAVLINK_MSG_ID_MEMORY_VECT, "MEMORY_VECT"},
    {MAVLINK_MSG_ID_DEBUG_VECT, "DEBUG_VECT"},
    {MAVLINK_MSG_ID_NAMED_VALUE_FLOAT, "NAMED_VALUE_FLOAT"},
    {MAVLINK_MSG_ID_NAMED_VALUE_INT, "NAMED_VALUE_INT"},
    {MAVLINK_MSG_ID_STATUSTEXT, "STATUSTEXT"},
    {MAVLINK_MSG_ID_DEBUG, "DEBUG"}
    // The following messages aren't in v1.
    // {MAVLINK_MSG_ID_SETUP_SIGNING, "SETUP_SIGNING"},
    // {MAVLINK_MSG_ID_BUTTON_CHANGE, "BUTTON_CHANGE"},
    // {MAVLINK_MSG_ID_PLAY_TUNE, "PLAY_TUNE"},
    // {MAVLINK_MSG_ID_CAMERA_INFORMATION, "CAMERA_INFORMATION"},
    // {MAVLINK_MSG_ID_CAMERA_SETTINGS, "CAMERA_SETTINGS"},
    // {MAVLINK_MSG_ID_STORAGE_INFORMATION, "STORAGE_INFORMATION"},
    // {MAVLINK_MSG_ID_CAMERA_CAPTURE_STATUS, "CAMERA_CAPTURE_STATUS"},
    // {MAVLINK_MSG_ID_CAMERA_IMAGE_CAPTURED, "CAMERA_IMAGE_CAPTURED"},
    // {MAVLINK_MSG_ID_FLIGHT_INFORMATION, "FLIGHT_INFORMATION"},
    // {MAVLINK_MSG_ID_MOUNT_STATUS, "MOUNT_STATUS"},
    // {MAVLINK_MSG_ID_LOGGING_DATA, "LOGGING_DATA"},
    // {MAVLINK_MSG_ID_LOGGING_DATA_ACKED, "LOGGING_DATA_ACKED"},
    // {MAVLINK_MSG_ID_LOGGING_ACK, "LOGGING_ACK"}
};


};  // namespace dfti
